[![DOI](https://zenodo.org/badge/163904331.svg)](https://zenodo.org/badge/latestdoi/163904331) 
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)

# agrid
A grid for modelling, analyse, map and visualise multidimensional and multivariate data. The module contains a class for generating grid objects with variables and functions that defines a multidimensional space with defined extent. 

Main features:
  - Labelled dimensions coordinates using xarray
  - Fast process of high resolution and low resolution data
  - Using dask arrays
  - 2D map plots and cross-sections
  - 3D visualisation
  - Features for modelling, analysis and visualisation
 
The repository contains: 
 - Module with class for functions and variables. 
 - Jupyter notebook tutorials:
  - 1. The grid object
  - 2. Import data
  - 3. Visualize data
  - 4. Introduction to processing and modelling using grid. 
 - TikZ code for e.g. generating illustrations. 

---
## Instructions: 

The package can be installed by adding it to your Python path, but can also be an incorporated part of you project. 

To start: 
Download module. 

Import agrid 

See example in the Jupyter Notebook agrid

---

## Future development: 

 - Software Meta-paper
 - Updates
 - Non regular grids
 - Hexagonal grids
 - More visualisation option
 - More developed and robust import functions